<?php

/**
 * Динамический блок
 *
 * $section_id = ID выводимого блока
 *
 * $array[] = массив для работы с полями динамического блока (необязательный аргумент)
 * 'fields' => [ '10' ] = регистрация дополнительных полей в массиве, где ключ - ID поля
 * 'fields_sort' => [ '10' => 'asc', 'title' => 'desc'  ] = сортировка массива по дополнительным и дефолтным полям
 * 'fields_filter' => '{id} > 5 && {10} > 100 && {title} != "Some text page"' = фильтрация массива по дополнительным и дефолтным полям, названия полей заключаются в фигурные скобки
 */

function cms_block_dynamic( $section_id, $array = [] )
{

	// Если динамический блок существует, то выводим данные
	if (cms_count_query('SELECT id from ' . DB_PREFIX . 'blocks_dynamic where id = ' . $section_id . ' && hide = 0') > 0)
	{

		$pdo = cms_pdo();
		extract($_GET);

		// Выборка данных из настроек блока
		$row_section = $pdo->query('SELECT * from ' . DB_PREFIX . 'blocks_dynamic where id = ' . $section_id . ' && hide = 0')->fetch();

		// Определяем базу данных блока
		if ($row_section['data_base'] != 0)
		{
			$reg = cms_sql('reg_start') . $row_section['data_base'] . cms_sql('reg_end');
		}
		else
		{
			$reg = cms_sql('reg_start') . $section_id . cms_sql('reg_end');
		}

		if ($row_section['code_where'] != '')
		{
			$where = $row_section['code_where'];
		}
		else
		{
			$where = 'dynamic_section REGEXP "' . $reg . '"';
		}

		// Подсчет и обработка элементов, входящих в динамический блок
		if(isset($array['fields']))
		{
			$rows = $pdo->query('SELECT * from ' . DB_PREFIX . $row_section['data_type'] . ' where ' . $where . ' && hide=0')->fetchAll(); // формируем отдельный массив для сортировки
			$rows = cmsArray::ArrayAdd( $rows, $array['fields'], 'blocks_dynamic' ); // регистрация дополнительных полей
			if(isset($array['fields_sort'])) $rows = cmsArray::ArraySort( $rows, $array['fields_sort'] ); // сортировка массива
			if(isset($array['fields_filter'])) $rows = cmsArray::ArrayFilter( $rows, $array ); // фильтрация массива
			$count_elements = count($rows);
		}
		else
		{
			$count_elements = $pdo->query('SELECT id from ' . DB_PREFIX . $row_section['data_type'] . ' where ' . $where . ' && hide=0')->rowCount();
		}

		// Предварительные переменные постраничного разделения
		if ($row_section['pagination'] == 1 && $row_section['limit2'] > 0 && $row_section['data_type'] == 'pages')
		{
			$links = $row_section['limit2']; // количество данных на странице
			$show_link = 8; // количество отображаемых ссылок; нагляднее будет, когда это число будет парное
			$last_text = '&laquo;'; // текст для ссылки на первую страницу
			$next_text = '&raquo;'; // текст для ссылки на последнюю страницу
			$separator = ''; // разделитель ссылок
			$page_string = 'page';

			// Шаблон пути ссылки (начало)
			if ($_SERVER['REQUEST_URI'] == '/' || $_SERVER['REQUEST_URI'] == '/index.php' || !isset($_GET['cms_translit']))
			{
				$template_pages1 = '/';
			}
			else
			{
				$template_pages1 = '/' . $_GET['cms_translit'] . '/';
			}

			$template_pages2 = ''; // шаблон пути ссылки (конец)

			if (!isset($_GET[$page_string]) || ($page = intval($_GET[$page_string])) < 1)
			{
				$page = 1;
			}
			else
			{
				$page = (int)$page;
			}

			$pages_count = ceil($count_elements / $links); // Количество страниц
			if ($page > $pages_count) $page = $pages_count;
			$page_for_query = $page - 1;
			$lpos = $page_for_query * $links;
		}

		// Обрамление (начало)
		if ($count_elements > 0 && $row_section['frame1'] != '')
		{
			eval(' ?>' . $row_section['frame1'] . '<?php ');
		}

		// Сортировка данных
		$sorting = ($row_section['code_sorting'] != '') ? $row_section['code_sorting'] : 'number asc, id asc';

		// Если не указано постраничное разделение
		if ($row_section['pagination'] == 0 && $row_section['limit2'] > 0)
		{
			$limit = 'limit ' . $row_section['limit1'] . ',' . $row_section['limit2'];
			$limit_sort1 = $row_section['limit1'];
			$limit_sort2 = $row_section['limit2'];
		}
		// Если указано постраничное разделение
		elseif ($row_section['pagination'] == 1 && $row_section['limit2'] > 0)
		{
			$limit = 'limit ' . $lpos . ',' . $row_section['limit2'];
			$limit_sort1 = $lpos;
			$limit_sort2 = $row_section['limit2'];
		}
		else
		{
			$limit = '';
			$limit_sort1 = '';
			$limit_sort2 = '';
		}

		// Если количество страниц больше нуля, то выводим динамический блок
		if ($count_elements != 0)
		{

			// Кастомное лимитирование
			if (isset($array['fields']))
			{
				$rows = cmsArray::ArrayLimit( $rows, $limit_sort1, $limit_sort2 );
			}

			// Лимитирование из админки
			else
			{
				$rows = $pdo->query('SELECT * from ' . DB_PREFIX . $row_section['data_type'] . ' where ' . $where . ' && hide=0 order by ' . $sorting . ' ' . $limit)->fetchAll();
			}

			foreach ($rows as $row)
			{

				$template_default = $row_section['template_default'];
				$template_checked = $row_section['template_checked'];
				$template_index_default = $row_section['template_index_default'];
				$template_index_checked = $row_section['template_index_checked'];

				/* Обработка вариантов заданных шаблонов */

				// Если заданы: Элемент (по умолчанию)
				if ($template_default != '' && $template_checked == '' && $template_index_default == '' && $template_index_checked == '')
				{

					eval(' ?>' . $template_default . '<?php ');
				}

				// Если заданы: Элемент (по умолчанию), Элемент (активный)
				elseif ($template_default != '' && $template_checked != '' && $template_index_default == '' && $template_index_checked == '')
				{

					if (isset($_GET['cms_translit']) && stristr(cmsPageURI::Display(), '/' . $row['translit'] . '/'))
					{
						eval(' ?>' . $template_checked . '<?php ');
					}
					else
					{
						eval(' ?>' . $template_default . '<?php ');
					}
				}

				// Если заданы: Элемент (по умолчанию), Элемент для главной страницы (по умолчанию)
				elseif ($template_default != '' && $template_checked == '' && $template_index_default != '' && $template_index_checked == '')
				{

					if (isset($row['page_index']) && $row['page_index'] == '1')
					{
						eval(' ?>' . $template_index_default . '<?php ');
					}
					else
					{
						eval(' ?>' . $template_default . '<?php ');
					}
				}

				// Если заданы все шаблоны
				elseif ($template_default != '' && $template_checked != '' && $template_index_default != '' && $template_index_checked != '')
				{

					if (isset($_GET['cms_translit']) && stristr(cmsPageURI::Display(), '/' . $row['translit'] . '/'))
					{
						eval(' ?>' . $template_checked . '<?php ');
					}
					elseif (isset($row['page_index']) && $row['page_index'] == '1')
					{
						if (!isset($_GET['cms_translit']))
						{
							eval(' ?>' . $template_index_checked . '<?php ');
						}
						else
						{
							eval(' ?>' . $template_index_default . '<?php ');
						}
					}
					else
					{
						eval(' ?>' . $template_default . '<?php ');
					}
				}
			}
		}

		// Обрамление (конец)
		if ($count_elements > 0 && $row_section['frame2'] != '')
		{
			eval(' ?>' . $row_section['frame2'] . '<?php ');
		}

		// Постраничный вывод
		if ($row_section['pagination'] == 1 && $row_section['limit2'] > 0 && $count_elements > $row_section['limit2'] && $row_section['data_type'] == 'pages')
		{

			$array_pagination =
				[
					'page' => $page,
					'page_string' => $page_string,
					'template_pages1' => $template_pages1,
					'template_pages2' => $template_pages2,
					'pages_count' => $pages_count,
					'show_link' => $show_link,
					'separator' => $separator,
					'last_text' => $last_text,
					'next_text' => $next_text
				];

			cms_pagination($array_pagination);
		}
	}
}
